@@ -1,8 +1,14 @@
 # -*- coding: utf-8 -*-
 
-__version__ = "0.0.16"
+__version__ = "0.0.22"
 __author__ = "BriFuture"
 
+"""
+Update Since 0.0.22, socket server has been improved a lot, interface has changed
+
+Update Since 0.0.17: scripts in `myscripts` folder could add more scripts
+without change main.py file.
+"""
 
 from .utils import createLogger, initGetText
 from ._constants import BFF_ROOT_PATH, BFF_OTHER_PATH
